Learn R Programming

pcensmix (version 1.2-1)

print.pcgen: Print Method for pcgen Objects

Description

This function prints the progressive censored data generated by the S3 class pcgen.

Usage

# S3 method for pcgen
print(x, ...)

Arguments

x

object of class pcgen.

...

optional arguments to pass by.

Value

This function uses the generic function print to print the dataset of class "pcgen" in a nice format.

Examples

Run this code
# NOT RUN {
## Generate a two component normal mixture data,
Pdat <- pcgen(r = 80, p = 0.3, data = mixgen(N = 100, dist1 = 'norm',
              dist2 = 'norm', control = list(12, 2, 14, 4, 0.3)))
# and print it.
print(Pdat)

# }

Run the code above in your browser using DataLab